package cn.iocoder.yudao.module.shop.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.shop.entity.ShopMallPartners;

import java.util.List;

/**
 * 合作商管理Service接口
 *
 * @author ruoyi
 * @date 2023-07-10
 */
public interface IShopMallPartnersService extends IService<ShopMallPartners>
{
    /**
     * 查询合作商管理
     *
     * @param partnerId 合作商管理主键
     * @return 合作商管理
     */
    public ShopMallPartners selectShopMallPartnersByPartnerId(Long partnerId);

    /**
     * 查询合作商管理列表
     *
     * @param shopMallPartners 合作商管理
     * @return 合作商管理集合
     */
    public IPage<ShopMallPartners> selectShopMallPartnersList(Page<ShopMallPartners> page, ShopMallPartners shopMallPartners);

    /**
     * 新增合作商管理
     *
     * @param shopMallPartners 合作商管理
     * @return 结果
     */
    public int insertShopMallPartners(ShopMallPartners shopMallPartners);

    /**
     * 修改合作商管理
     *
     * @param shopMallPartners 合作商管理
     * @return 结果
     */
    public int updateShopMallPartners(ShopMallPartners shopMallPartners);
    public int setShopAdmin(ShopMallPartners shopMallPartners);


    /**
     * 批量删除合作商管理
     *
     * @param partnerIds 需要删除的合作商管理主键集合
     * @return 结果
     */
    public int deleteShopMallPartnersByPartnerIds(Long[] partnerIds);

    /**
     * 删除合作商管理信息
     *
     * @param partnerId 合作商管理主键
     * @return 结果
     */
    public int deleteShopMallPartnersByPartnerId(Long partnerId);


    public ShopMallPartners selectShopMallPartnersByUserId(Long userId,String type);

    List<ShopMallPartners> selectShopMallPartnersListWx(ShopMallPartners shopMallPartners);
}
